import colorful

colorful.use_true_colors()

primary = colorful.purple1
info = colorful.lightBlue
mute = colorful.gray
success = colorful.green
normal = colorful.darkGray
danger = colorful.red3
light = colorful.white
warning = colorful.orange
dark = colorful.black
